@@ -11,7 +11,7 @@ use crate::{
 };
 
 /// Trait that implements a thread-safe, concurrent low-level content addressed store.
-pub trait ContentAddrStore: Send + Sync {
+pub trait ContentAddrStore: Send + Sync + 'static {
     /// Gets a block by hash.
     fn get<'a>(&'a self, key: &[u8]) -> Option<Cow<'a, [u8]>>;
 
@@ -59,6 +59,14 @@ pub struct Database<C: ContentAddrStore> {
     cas: Arc<C>,
 }
 
+impl<C: ContentAddrStore> Clone for Database<C> {
+    fn clone(&self) -> Self {
+        Self {
+            cas: self.cas.clone(),
+        }
+    }
+}
+
 impl<C: ContentAddrStore> Database<C> {
     /// Create a new Database.
     pub fn new(cas: C) -> Self {
@@ -180,7 +188,7 @@ impl<C: ContentAddrStore> Tree<C> {
                                 opf(Hashed::default());
                             }
                             assert!(high4(single_ikey) != high4(ikey));
-                            opf(singleton_smt_root(diverging_height, single_key, &data));
+                            opf(singleton_smt_root(diverging_height - 1, single_key, &data));
                         }
                         return Cow::Owned(Vec::new());
                     }
